@@ -73,7 +73,7 @@ class GeneHandler(object):
         projection["start"] = 1
         projection["end"] = 1
 
-        LOG.debug("Fetching gene %s" % hgnc_identifier)
+        LOG.debug("Fetching gene (light) %s" % hgnc_identifier)
         gene_symbol_obj = self.hgnc_collection.find_one(query, projection)
         if not gene_symbol_obj:
             return None
@@ -159,7 +159,10 @@ class GeneHandler(object):
 
         if search:
             # first search for a full match
-            query_full_match = {**self.get_query_alias_or_id(hgnc_symbol, build), **build_query}
+            query_full_match = {
+                **self.get_query_alias_or_id(hgnc_symbol, build),
+                **build_query,
+            }
             nr_genes = self.nr_genes(query=query_full_match)
             if nr_genes != 0:
                 return self.hgnc_collection.find(query_full_match)
