@@ -47,7 +47,10 @@ from scout.utils.scout_requests import delete_request_json, post_request_json
 LOG = logging.getLogger(__name__)
 
 STATUS_MAP = {"solved": "bg-success", "archived": "bg-warning"}
-JSON_HEADERS = {"Content-type": "application/json; charset=utf-8", "Accept": "text/json"}
+JSON_HEADERS = {
+    "Content-type": "application/json; charset=utf-8",
+    "Accept": "text/json",
+}
 
 
 def case(store, institute_obj, case_obj):
@@ -127,6 +130,7 @@ def case(store, institute_obj, case_obj):
         panel_version = panel_info.get("version")
         panel_obj = store.gene_panel(panel_name, version=panel_version)
         latest_panel = store.gene_panel(panel_name)
+        panel_info["removed"] = False if latest_panel is None else latest_panel.get("hidden", False)
         if not panel_obj:
             panel_obj = latest_panel
             if not panel_obj:
@@ -214,8 +218,10 @@ def case(store, institute_obj, case_obj):
 
     if case_obj.get("custom_images"):
         # re-encode images as base64
-        for img_section in case_obj["custom_images"].values():
-            for img in img_section:
+        if "case" in case_obj.get("custom_images"):
+            case_obj["custom_images"] = case_obj["custom_images"]["case"]
+        for img_section in case_obj["custom_images"].keys():
+            for img in case_obj["custom_images"][img_section]:
                 img["data"] = b64encode(img["data"]).decode("utf-8")
 
     data = {
@@ -776,8 +782,8 @@ def hpo_diseases(username, password, hpo_ids, p_value_treshold=1):
         results = query_phenomizer.query(username, password, *hpo_ids)
         diseases = [result for result in results if result["p_value"] <= p_value_treshold]
         return diseases
-    except SystemExit:
-        return None
+    except RuntimeError:
+        flash("Could not establish a conection to Phenomizer", "danger")
 
 
 def rerun(store, mail, current_user, institute_id, case_name, sender, recipient):
@@ -1115,10 +1121,11 @@ def matchmaker_add(request, institute_id, case_name):
     # Check that general MME request requirements are fulfilled
     matchmaker_check_requirements(request)
     _, case_obj = institute_and_case(store, institute_id, case_name)
-    candidate_vars = case_obj.get("suspects") or []
+    candidate_vars = request.form.getlist("selected_var")
+
     if len(candidate_vars) > 3:
         flash(
-            "At the moment it is not possible to save to MatchMaker more than 3 pinned variants",
+            "At the moment it is not possible to save to MatchMaker more than 3 candidate variants / genes",
             "warning",
         )
         return redirect(request.referrer)
@@ -1182,7 +1189,7 @@ def matchmaker_add(request, institute_id, case_name):
 
         if candidate_vars:
             g_features = genomic_features(
-                store, case_obj, individual.get("display_name"), genes_only
+                store, case_obj, individual.get("display_name"), candidate_vars, genes_only
             )
             patient["genomicFeatures"] = g_features
         resp = matchmaker.patient_submit(patient)
@@ -1195,9 +1202,7 @@ def matchmaker_add(request, institute_id, case_name):
         )
         if resp.get("status_code") != 200:
             flash(
-                "an error occurred while adding patient to matchmaker: {}".format(
-                    resp.get("message")
-                ),
+                "an error occurred while adding patient to matchmaker: {}".format(resp),
                 "warning",
             )
             continue
@@ -1235,7 +1240,10 @@ def matchmaker_delete(request, institute_id, case_name):
             user_obj = store.user(current_user.email)
             store.case_mme_delete(case_obj=case_obj, user_obj=user_obj)
 
-            flash(f"Deleted patient '{patient_id}', case '{case_name}' from MatchMaker", "success")
+            flash(
+                f"Deleted patient '{patient_id}', case '{case_name}' from MatchMaker",
+                "success",
+            )
             continue
 
         flash(f"An error occurred while deleting patient from MatchMaker", "danger")
@@ -1256,14 +1264,22 @@ def matchmaker_matches(request, institute_id, case_name):
     matchmaker_check_requirements(request)
 
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    data = {"institute": institute_obj, "case": case_obj, "server_errors": [], "panel": 1}
+    data = {
+        "institute": institute_obj,
+        "case": case_obj,
+        "server_errors": [],
+        "panel": 1,
+    }
     matches = {}
     for patient in case_obj.get("mme_submission", {}).get("patients", []):
         patient_id = patient["id"]
         matches[patient_id] = None
         server_resp = matchmaker.patient_matches(patient_id)
         if server_resp.get("status_code") != 200:  # server returned error
-            flash("MatchMaker server returned error:{}".format(data["server_errors"]), "danger")
+            flash(
+                "MatchMaker server returned error:{}".format(data["server_errors"]),
+                "danger",
+            )
             return redirect(request.referrer)
         # server returned a valid response
         pat_matches = []
