@@ -1,4 +1,5 @@
 import logging
+from base64 import b64encode
 from datetime import date
 
 from flask import url_for
@@ -82,7 +83,7 @@ def tx_overview(variant_obj):
                 decorated_tx = None
                 if ovw_tx["mane"] and ovw_tx["mane"].startswith(refseq_id):
                     decorated_tx = ovw_tx["mane"]
-                elif ovw_tx["mane_plus"] and ovw_tx["mane_plus"].starstwith(refseq_id):
+                elif ovw_tx["mane_plus"] and ovw_tx["mane_plus"].startswith(refseq_id):
                     decorated_tx = ovw_tx["mane_plus"]
                 elif refseq_id.startswith("XM"):
                     ovw_tx["muted_refseq_ids"].append(refseq_id)
@@ -349,6 +350,11 @@ def variant(
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
         }
 
+    # re-encode images as base64
+    if variant_obj.get("custom_images"):
+        for img in variant_obj["custom_images"]:
+            img["data"] = b64encode(img["data"]).decode("utf-8")
+
     tx_overview(variant_obj)
 
     return {
@@ -428,6 +434,8 @@ def observations(store, loqusdb, case_obj, variant_obj):
 
     if not obs_data:
         obs_data["total"] = loqusdb.case_count(variant_category=category, loqusdb_id=loqusdb_id)
+        if obs_data["total"]:
+            obs_data["observations"] = 0
         return obs_data
 
     user_institutes_ids = set([inst["_id"] for inst in user_institutes(store, current_user)])
@@ -448,7 +456,7 @@ def observations(store, loqusdb, case_obj, variant_obj):
         other_institutes.update(set(other_case.get("collaborators", [])))
 
         if user_institutes_ids.isdisjoint(other_institutes):
-            # If the user does not have access to the information we skip it
+            # If the user does not have access to the information we skip it. Admins allowed by user_institutes.
             continue
 
         other_variant = store.variant(
