@@ -14,12 +14,14 @@ from wtforms import (
     SelectMultipleField,
     StringField,
     SubmitField,
-    TextField,
     validators,
 )
 from wtforms.widgets import TextInput
 
 from scout.constants import (
+    CLINICAL_FILTER_BASE,
+    CLINICAL_FILTER_BASE_CANCER,
+    CLINICAL_FILTER_BASE_SV,
     CLINSIG_MAP,
     FEATURE_TYPES,
     GENETIC_MODELS,
@@ -134,6 +136,9 @@ class FiltersForm(VariantFiltersForm):
     clinical_filter = SubmitField(label="Clinical filter")
     clinvar_tag = BooleanField("ClinVar hits")
 
+    # polymorphic constant base for clinical filter
+    clinical_filter_base = CLINICAL_FILTER_BASE
+
 
 class CancerFiltersForm(VariantFiltersForm):
     """Base filters for CancerFiltersForm - extends VariantsFiltersForm"""
@@ -150,6 +155,9 @@ class CancerFiltersForm(VariantFiltersForm):
     cosmic_tag = BooleanField("Cosmic hits")
     mvl_tag = BooleanField("Managed Variants hits")
 
+    # polymorphic constant base for clinical filter
+    clinical_filter_base = CLINICAL_FILTER_BASE_CANCER
+
 
 class StrFiltersForm(VariantFiltersForm):
     """docstring for StrFiltersForm"""
@@ -158,10 +166,35 @@ class StrFiltersForm(VariantFiltersForm):
 class SvFiltersForm(VariantFiltersForm):
     """Extends FiltersForm for structural variants"""
 
-    size = TextField("Length")
+    size = StringField("Length")
     size_shorter = BooleanField("Length shorter than")
     svtype = SelectMultipleField("SVType", choices=SV_TYPE_CHOICES)
     decipher = BooleanField("Decipher")
     clingen_ngi = IntegerField("ClinGen NGI obs")
     swegen = IntegerField("SweGen obs")
     clinical_filter = SubmitField(label="Clinical filter")
+
+    # polymorphic constant base for clinical filter
+    clinical_filter_base = CLINICAL_FILTER_BASE_SV
+
+
+class CancerSvFiltersForm(SvFiltersForm):
+    """Extends SvFiltersForm for cancer structural variants"""
+
+    depth = IntegerField("Depth >", validators=[validators.Optional()])
+    alt_count = IntegerField("Min alt count", validators=[validators.Optional()])
+    control_frequency = BetterDecimalField(
+        "Normal alt AF <", places=2, validators=[validators.Optional()]
+    )
+    tumor_frequency = BetterDecimalField(
+        "Tumor alt AF >", places=2, validators=[validators.Optional()]
+    )
+
+
+FILTERSFORMCLASS = {
+    "snv": FiltersForm,
+    "str": StrFiltersForm,
+    "sv": SvFiltersForm,
+    "cancer_sv": CancerSvFiltersForm,
+    "cancer": CancerFiltersForm,
+}
