@@ -88,7 +88,7 @@ def variants(institute_id, case_name):
     controllers.populate_chrom_choices(form, case_obj)
 
     # populate available panel choices
-    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
+    form.gene_panels.choices = controllers.gene_panel_choices(store, institute_obj, case_obj)
 
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
@@ -124,7 +124,10 @@ def variants(institute_id, case_name):
         return controllers.download_variants(store, case_obj, variants_query)
 
     data = controllers.variants(store, institute_obj, case_obj, variants_query, result_size, page)
-    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
+    expand_search = request.method == "POST" and request.form.get("expand_search") in [
+        "True",
+        "",
+    ]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -181,7 +184,7 @@ def str_variants(institute_id, case_name):
     controllers.populate_chrom_choices(form, case_obj)
 
     # populate available panel choices
-    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
+    form.gene_panels.choices = controllers.gene_panel_choices(store, institute_obj, case_obj)
 
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
@@ -277,7 +280,10 @@ def sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
+    expand_search = request.method == "POST" and request.form.get("expand_search") in [
+        "True",
+        "",
+    ]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -358,7 +364,7 @@ def cancer_variants(institute_id, case_name):
     # Populate chromosome select choices
     controllers.populate_chrom_choices(form, case_obj)
 
-    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
+    form.gene_panels.choices = controllers.gene_panel_choices(store, institute_obj, case_obj)
     genome_build = "38" if "38" in str(case_obj.get("genome_build")) else "37"
     cytobands = store.cytoband_by_chrom(genome_build)
 
@@ -448,7 +454,10 @@ def cancer_sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
+    expand_search = request.method == "POST" and request.form.get("expand_search") in [
+        "True",
+        "",
+    ]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -502,11 +511,17 @@ def upload_panel(institute_id, case_name):
     # HTTP redirect code 307 asks that the browser preserves the method of request (POST).
     if category == "sv":
         return redirect(
-            url_for(".sv_variants", institute_id=institute_id, case_name=case_name, **form.data),
+            url_for(
+                ".sv_variants",
+                institute_id=institute_id,
+                case_name=case_name,
+                **form.data,
+            ),
             code=307,
         )
     return redirect(
-        url_for(".variants", institute_id=institute_id, case_name=case_name, **form.data), code=307
+        url_for(".variants", institute_id=institute_id, case_name=case_name, **form.data),
+        code=307,
     )
 
 
